#Demo agent services - index
Here you can find a number of already deployed services that showcase the potential
of the {{open_autonomy}} framework. You can fetch the  services (and/or 
the corresponding agents) from the remote IPFS registry and explore them by yourself.

- [Hello world agent service](hello_world_demo.md): a demo service to showcase
  how to use the main components in an agent service,  without external interactions.
- [Price oracle demo](price_oracle_intro.md): a full service implementing a
  price oracle where each agent collects price estimates from a different source.
  